==> otyacraftengine-fabric-2.2-build1-sources.jar: dev/felnull/otyacraftengine/client/renderer/blockentity/TestRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.blockentity;

import dev.architectury.registry.client.rendering.BlockEntityRendererRegistry;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.blockentity.TestBlockEntity;
import dev.felnull.otyacraftengine.client.util.OEModelUtil;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import net.minecraft.class_2246;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_5614;
import var;

public class TestRenderer extends AbstractBlockEntityRenderer<TestBlockEntity> {

    public TestRenderer(class_5614.class_5615 context) {
        super(context);
    }

    @Override
    public void render(TestBlockEntity blockEntity, float f, class_4587 poseStack, class_4597 multiBufferSource, int i, int j) {
        // OERenderUtil.renderTextSprite(poseStack, multiBufferSource, new TextComponent("TEST"), 0, 0, 0, 1f, 0, 0, 0xFF0000FF, i);
        //     Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), ItemTransforms.TransformType.FIXED, i, j, poseStack, multiBufferSource, 0);
        //      var vc = multiBufferSource.getBuffer(RenderType.lines());
        //      LevelRenderer.renderVoxelShape(poseStack, vc, Blocks.ANVIL.defaultBlockState().getShape(blockEntity.getLevel(), blockEntity.getBlockPos()), 0, 0, 0, 0, 0, 0, 0);
        var model = OEModelUtil.getModel(new class_2960(OtyacraftEngine.MODID, "block/test_model"));//OERenderUtil.getBlockModel(Blocks.STONE.defaultBlockState());
        var vc = multiBufferSource.getBuffer(class_4722.method_24074());
        poseStack.method_22903();
        float rot = class_3532.method_16439(f, blockEntity.getOldRoted(), blockEntity.getRoted());

        if (class_310.method_1551().field_1687.method_8320(blockEntity.method_11016().method_10074()).method_26204() == class_2246.field_10535) {
            rot = blockEntity.getRoted();
        } else if (class_310.method_1551().field_1687.method_8320(blockEntity.method_11016().method_10074()).method_26204() == class_2246.field_10201) {
            rot = class_3532.method_16439(f, blockEntity.getRoted() - 3, blockEntity.getRoted());
        }
        poseStack.method_22904(0.5f, 0.5f, 0.5f);
        OERenderUtil.poseRotateX(poseStack, rot);
        OERenderUtil.poseRotateY(poseStack, rot);
        OERenderUtil.poseRotateZ(poseStack, rot);

        poseStack.method_22904(-0.5f, -0.5f, -0.5f);
        OERenderUtil.renderModel(poseStack, vc, model, i, j);
        poseStack.method_22909();
    }

    public static void init() {
        BlockEntityRendererRegistry.register(TestBlockEntity.TEST_BLOCKENTITY, TestRenderer::new);
    }
}

==> otyacraftengine-fabric-2.11-build1-sources.jar: dev/felnull/otyacraftengine/client/renderer/blockentity/TestRenderer.java <==
package dev.felnull.otyacraftengine.client.renderer.blockentity;

import dev.architectury.registry.client.rendering.BlockEntityRendererRegistry;
import dev.felnull.otyacraftengine.OtyacraftEngine;
import dev.felnull.otyacraftengine.blockentity.TestBlockEntity;
import dev.felnull.otyacraftengine.client.util.OEModelUtil;
import dev.felnull.otyacraftengine.client.util.OERenderUtil;
import net.minecraft.class_2246;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3532;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_4722;
import net.minecraft.class_5614;
import var;

public class TestRenderer extends AbstractBlockEntityRenderer<TestBlockEntity> {

    public TestRenderer(class_5614.class_5615 context) {
        super(context);
    }

    @Override
    public void render(TestBlockEntity blockEntity, float f, class_4587 poseStack, class_4597 multiBufferSource, int i, int j) {
        // OERenderUtil.renderTextSprite(poseStack, multiBufferSource, new TextComponent("TEST"), 0, 0, 0, 1f, 0, 0, 0xFF0000FF, i);
        //     Minecraft.getInstance().getItemRenderer().renderStatic(new ItemStack(Items.APPLE), ItemTransforms.TransformType.FIXED, i, j, poseStack, multiBufferSource, 0);
        //      var vc = multiBufferSource.getBuffer(RenderType.lines());
        //      LevelRenderer.renderVoxelShape(poseStack, vc, Blocks.ANVIL.defaultBlockState().getShape(blockEntity.getLevel(), blockEntity.getBlockPos()), 0, 0, 0, 0, 0, 0, 0);
        var model = OEModelUtil.getModel(new class_2960(OtyacraftEngine.MODID, "block/test_model"));//OERenderUtil.getBlockModel(Blocks.STONE.defaultBlockState());
        var vc = multiBufferSource.getBuffer(class_4722.method_24074());
        poseStack.method_22903();
        float rot = class_3532.method_16439(f, blockEntity.getOldRoted(), blockEntity.getRoted());

        if (class_310.method_1551().field_1687.method_8320(blockEntity.method_11016().method_10074()).method_26204() == class_2246.field_10535) {
            rot = blockEntity.getRoted();
        } else if (class_310.method_1551().field_1687.method_8320(blockEntity.method_11016().method_10074()).method_26204() == class_2246.field_10201) {
            rot = class_3532.method_16439(f, blockEntity.getRoted() - 3, blockEntity.getRoted());
        }
        poseStack.method_22904(0.5f, 0.5f, 0.5f);
        OERenderUtil.poseRotateX(poseStack, rot);
        OERenderUtil.poseRotateY(poseStack, rot);
        OERenderUtil.poseRotateZ(poseStack, rot);

        poseStack.method_22904(-0.5f, -0.5f, -0.5f);
        OERenderUtil.renderModel(poseStack, vc, model, i, j);
        poseStack.method_22909();
    }

    public static void init() {
        BlockEntityRendererRegistry.register(TestBlockEntity.TEST_BLOCKENTITY.get(), TestRenderer::new);
    }
}
